@@ -2,7 +2,7 @@
 * dvbinput.cpp: DVB streams
 *-------------------------------------------------------------------------------
 * (c)1999-2002 VideoLAN
-* $Id: dvbinput.cpp,v 1.21.4.3 2003/03/08 14:03:35 nitrox Exp $
+* $Id: dvbinput.cpp,v 1.21.4.6 2004/01/10 21:54:57 alexis Exp $
 *
 * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
 *          Damien Lucas <nitrox@videolan.org>
@@ -182,7 +182,7 @@ void C_DvbInput::OnInit()
 
   // Enable DVR (sets the DMX_OUT_TS_TAP in the lib)
   dvb->enable_DVR();
-  if(m_bHasDecoder) dvb->enable_DVR_other();
+  dvb->enable_DVR_other();
 
   //Get the .dvbrc file
   if (!get_dvbrc(filen,*dvb,iNumber,FILELEN))
