@@ -2,7 +2,7 @@
 * filereader.cpp: file reader
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: filereader.cpp,v 1.4 2002/07/12 14:38:56 jpsaman Exp $
+* $Id: filereader.cpp,v 1.4.4.1 2003/05/16 19:43:59 nitrox Exp $
 *
 * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
 *
@@ -127,7 +127,7 @@ int C_FileMpegReader::Read(byte* pBuff, int iSize)
   {
     int iRc = m_cFile.Read(pBuff, iSize);
     // Loop on stream and set the discontinuity flag
-    if((iRc == FILE_EOF) && m_bLoop)
+    if((iRc<0) && m_bLoop)
     {
       m_cFile.Seek(0, FILE_SEEK_BEGIN);
       m_bDiscontinuity = true;
